==> codedeploy-0.34.0-sources.jar: software/amazon/awscdk/services/codedeploy/ILambdaDeploymentGroup.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * Interface for a Lambda deployment groups.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.2 (build 27d16c2)", date = "2019-06-10T11:15:38.106Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ILambdaDeploymentGroup extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.IResource {
    /**
     * The reference to the CodeDeploy Lambda Application that this Deployment Group belongs to.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.codedeploy.ILambdaApplication getApplication();
    /**
     * The ARN of this Deployment Group.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getDeploymentGroupArn();
    /**
     * The physical name of the CodeDeploy Deployment Group.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getDeploymentGroupName();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codedeploy.ILambdaDeploymentGroup {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The reference to the CodeDeploy Lambda Application that this Deployment Group belongs to.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public software.amazon.awscdk.services.codedeploy.ILambdaApplication getApplication() {
            return this.jsiiGet("application", software.amazon.awscdk.services.codedeploy.ILambdaApplication.class);
        }

        /**
         * The ARN of this Deployment Group.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public java.lang.String getDeploymentGroupArn() {
            return this.jsiiGet("deploymentGroupArn", java.lang.String.class);
        }

        /**
         * The physical name of the CodeDeploy Deployment Group.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public java.lang.String getDeploymentGroupName() {
            return this.jsiiGet("deploymentGroupName", java.lang.String.class);
        }

        /**
         * The construct node in the scope tree.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public software.amazon.awscdk.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.ConstructNode.class);
        }
    }
}

==> codedeploy-0.35.0-sources.jar: software/amazon/awscdk/services/codedeploy/ILambdaDeploymentGroup.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * Interface for a Lambda deployment groups.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.3 (build 464b8c6)", date = "2019-06-19T15:19:43.954Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ILambdaDeploymentGroup extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.IResource {
    /**
     * The reference to the CodeDeploy Lambda Application that this Deployment Group belongs to.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    software.amazon.awscdk.services.codedeploy.ILambdaApplication getApplication();
    /**
     * The ARN of this Deployment Group.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getDeploymentGroupArn();
    /**
     * The physical name of the CodeDeploy Deployment Group.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.String getDeploymentGroupName();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codedeploy.ILambdaDeploymentGroup {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The reference to the CodeDeploy Lambda Application that this Deployment Group belongs to.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public software.amazon.awscdk.services.codedeploy.ILambdaApplication getApplication() {
            return this.jsiiGet("application", software.amazon.awscdk.services.codedeploy.ILambdaApplication.class);
        }

        /**
         * The ARN of this Deployment Group.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public java.lang.String getDeploymentGroupArn() {
            return this.jsiiGet("deploymentGroupArn", java.lang.String.class);
        }

        /**
         * The physical name of the CodeDeploy Deployment Group.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public java.lang.String getDeploymentGroupName() {
            return this.jsiiGet("deploymentGroupName", java.lang.String.class);
        }

        /**
         * The physical (that is, visible in the AWS Console) name of this resource.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public software.amazon.awscdk.PhysicalName getPhysicalName() {
            return this.jsiiGet("physicalName", software.amazon.awscdk.PhysicalName.class);
        }

        /**
         * The construct node in the scope tree.
         * 
         * EXPERIMENTAL
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public software.amazon.awscdk.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.ConstructNode.class);
        }
    }
}
